]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - mp4.c
mp4: Rename mp4_total_tracks() to mp4_get_total_tracks().
[paraslash.git] / mp4.c
diff --git a/mp4.c b/mp4.c
index 477b4307244731a0702599c8e49cf2a89862efa3..49ab1371fbff23dd202555a656dd78c84d7b969b 100644 (file)
--- a/mp4.c
+++ b/mp4.c
@@ -61,11 +61,6 @@ struct mp4 {
        struct mp4_metadata meta;
 };
 
-int32_t mp4_total_tracks(const struct mp4 *f)
-{
-       return f->total_tracks;
-}
-
 /*
  * Returns -1, 0, or 1 on errors/EOF/success. Partial reads followed by EOF or
  * read errors are treated as errors.
@@ -1084,7 +1079,7 @@ static int32_t sample_to_offset(const struct mp4 *f, int32_t track,
  * Return the number of milliseconds of the given track.
  *
  * \param f As returned by \ref mp4_open_read(), must not be NULL.
* \param track Between zero and the value returned by \ref mp4_total_tracks().
  *
  * The function returns zero if the audio file is of zero length or contains a
  * corrupt track header.
@@ -1098,6 +1093,11 @@ uint64_t mp4_get_duration(const struct mp4 *f, int32_t track)
        return t->duration * 1000 / t->timeScale;
 }
 
+int32_t mp4_get_total_tracks(const struct mp4 *f)
+{
+       return f->total_tracks;
+}
+
 /**
  * Check whether the given track number corresponds to an audio track.
  *
@@ -1084,7 +1079,7 @@ static int32_t sample_to_offset(const struct mp4 *f, int32_t track,
  *
  * \param f As returned by \ref mp4_open_read(), must not be NULL.
- * \param track Between zero and the value returned by \ref mp4_total_tracks().
+ * \param track Between zero and the value returned by \ref mp4_get_total_tracks().
  *
  * The function returns zero if the audio file is of zero length or contains a